#
# $Id: Build.PL,v 296d7d2cdb25 2015/03/19 06:11:01 gomor $
#
use strict;
use warnings;

use Module::Build;

my $builder = Module::Build->new(
   module_name => 'Metabrik::Repository',
   license => 'bsd',
   dist_author => 'GomoR <gomor_at_metabrik.org>',
   dist_version_from => 'lib/Metabrik/Repository.pm',
   requires => {
      'perl' => '5.6.1',
      'Metabrik' => '1.08',
      'Config::Tiny' => 0,
      'Data::Dumper' => 0,
      'DateTime' => 0,
      'DateTime::Format::Mail' => 0,
      'DateTime::TimeZone' => 0,
      'DBD::SQLite' => 0,
      'DBI' => 0,
      'Email::Folder' => 0,
      'Email::Simple' => 0,
      'File::Find' => 0,
      'GnuPG::Interface' => 0,
      'Gzip::Faster' => 0,
      'HTTP::Proxy' => 0,
      'HTTP::Server::Brick' => 0,
      'IO::All' => 0,
      'IO::Handle' => 0,
      'IO::Scalar' => 0,
      'IO::Select' => 0,
      'IO::Socket::INET' => 0,
      'IO::Socket::INET6' => 0,
      'IO::Socket::Multicast' => 0,
      'IO::Socket::SSL' => 0,
      'JSON::XS' => 0,
      'List::Util' => 0,
      'LWP::ConnCache' => 0,
      'LWP::Protocol::connect' => 0,
      'LWP::UserAgent' => 0,
      'MIME::Base64' => 0,
      'NetAddr::IP' => 0,
      'Net::CIDR' => 0,
      'Net::Cmd' => 0,
      'Net::DNS::Nameserver::Trivial' => 0,
      'Net::DNS' => 0,
      'Net::Frame' => 0,
      'Net::Frame::Dump' => 0,
      'Net::Frame::Layer::ICMPv4' => 0,
      'Net::Frame::Layer::ICMPv6' => 0,
      'Net::Frame::Layer::IPv6' => 0,
      'Net::Frame::Simple' => 0,
      'Net::FTP' => 0,
      'Net::IPv4Addr' => 0,
      'Net::IPv6Addr' => 0,
      'Net::Libdnet' => 0,
      'Net::NBName' => 0,
      'Net::Netmask' => 0,
      'Net::Pcap' => 0,
      'Net::Routing' => 0,
      'Net::Server' => 0,
      'Net::SinFP3' => 0,
      'Net::SMTP' => 0,
      'NetSNMP::agent' => 0,
      'NetSNMP::ASN' => 0,
      'Net::SNMPTrapd' => 0,
      'Net::SSH2' => 0,
      'Net::SSLeay' => 0,
      'Net::Whois::Raw' => 0,
      'Net::Write' => 0,
      'Net::Write::Fast' => 0,
      'POSIX' => 0,
      'Redis' => 0,
      'Search::Elasticsearch' => 0,
      'Storable' => 0,
      'String::Random' => 0,
      'Term::ANSIColor' => 0,
      'Term::ReadPassword' => 0,
      'Text::CSV' => 0,
      'URI' => 0,
      'URI::Escape' => 0,
      'vFeed' => 0,
      'WWW::Mechanize' => 0,
      'WWW::Mechanize::PhantomJS' => 0,
      'XML::Simple' => 0,
   },
);

$builder->create_build_script;
