#
# $Id: Repository.pm,v 8f9a6571abfb 2015/03/09 19:54:34 gomor $
#
package Metabrik::Repository;
use strict;
use warnings;

our $VERSION = '1.08';

1;

__END__

=head1 NAME

Metabrik::Repository - Metabrik Briks repository

=head1 COPYRIGHT AND LICENSE

Copyright (c) 2014-2015, Patrice E<lt>GomoRE<gt> Auffret

You may distribute this module under the terms of The BSD 3-Clause License.
See LICENSE file in the source distribution archive.

=head1 AUTHOR

Patrice E<lt>GomoRE<gt> Auffret

=cut
